@@ -1,8 +1,8 @@
-import subprocess
 import textwrap
 
 from cloudmesh.common.console import Console
 from cloudmesh.common.util import writefile
+from cloudmesh.common.sudo import Sudo
 
 
 class Wifi:
@@ -18,26 +18,26 @@ class Wifi:
                 psk="{password}"
                 key_mgmt=WPA-PSK
         }}
-    """)
+    """)  # noqa: W293
 
     @staticmethod
-    def set(ssid, password, dryrun=False):
+    def set(ssid, password, location=None, sudo=False, dryrun=False):
+        location = location or Wifi.location
+
         if ssid is None or password is None:
             Console.error("SSID or password not set")
         if dryrun:
             password = "********"
-        config = Wifi.template.format(**locals()) \
-            .replace("BEGIN", "{").replace("END", "}")
+        config = Wifi.template.format(**locals())
         if dryrun:
-            print(Wifi.location)
+            print(location)
             print(config)
         else:
             try:
-                writefile(Wifi.location, config)
-            except FileNotFoundError as e:
-                Console.error(f"The file does not exist: {Wifi.location}")
+                if sudo:
+                    Sudo.writefile(location, config)
+                else:
+                    writefile(location, config)
 
-    @staticmethod
-    def is_root():
-        username = subprocess.getoutput("whoami")
-        return username == "root"
+            except FileNotFoundError as e:  # noqa: F841
+                Console.error(f"The file does not exist: {location}")
